@@ -1,5 +1,5 @@
 /* -*- mode: C; mode: fold -*-
-Copyright (C) 2010-2016 John E. Davis
+Copyright (C) 2010-2011 John E. Davis
 
 This file is part of the S-Lang Library.
 
@@ -177,7 +177,7 @@ static int _pcre_exec (void)
    SLang_MMT_Type *mmt;
    char *str;
    SLang_BString_Type *bstr = NULL;
-   SLstrlen_Type len;
+   unsigned int len;
    int pos = 0;
    int options = 0;
    int ret = -1;
@@ -233,7 +233,7 @@ free_and_return:
 }
 
 static int get_nth_start_stop (PCRE_Type *pt, unsigned int n,
-			       SLstrlen_Type *a, SLstrlen_Type *b)
+			       unsigned int *a, unsigned int *b)
 {
    int start, stop;
 
@@ -252,7 +252,7 @@ static int get_nth_start_stop (PCRE_Type *pt, unsigned int n,
 
 static void _pcre_nth_match (PCRE_Type *pt, int *np)
 {
-   SLuindex_Type start, stop;
+   unsigned int start, stop;
    SLang_Array_Type *at;
    SLindex_Type two = 2;
    int *data;
@@ -274,8 +274,8 @@ static void _pcre_nth_match (PCRE_Type *pt, int *np)
 
 static void _pcre_nth_substr (PCRE_Type *pt, char *str, int *np)
 {
-   SLstrlen_Type start, stop;
-   SLstrlen_Type len;
+   unsigned int start, stop;
+   unsigned int len;
 
    len = strlen (str);
 
@@ -312,12 +312,12 @@ static void _pcre_nth_substr (PCRE_Type *pt, char *str, int *np)
 static char *_slang_to_pcre (char *slpattern)
 {
    char *pattern, *p, *s;
-   SLstrlen_Type len;
+   unsigned int len;
    int in_bracket;
    char ch;
 
    len = strlen (slpattern);
-   pattern = (char *)SLmalloc (3*len + 1);
+   pattern = SLmalloc (3*len + 1);
    if (pattern == NULL)
      return NULL;
 
@@ -432,149 +432,20 @@ static SLang_Intrin_Fun_Type PCRE_Intrinsics [] =
 static SLang_IConstant_Type PCRE_Consts [] =
 {
    /* compile options */
-#ifndef PCRE_ANCHORED
-# define PCRE_ANCHORED 0
-#endif
    MAKE_ICONSTANT("PCRE_ANCHORED", PCRE_ANCHORED),
-#ifndef PCRE_AUTO_CALLOUT
-# define PCRE_AUTO_CALLOUT 0
-#endif
-   MAKE_ICONSTANT("PCRE_AUTO_CALLOUT", PCRE_AUTO_CALLOUT),
-#ifndef PCRE_BSR_ANYCRLF
-# define PCRE_BSR_ANYCRLF 0
-#endif
-   MAKE_ICONSTANT("PCRE_BSR_ANYCRLF", PCRE_BSR_ANYCRLF),
-#ifndef PCRE_BSR_UNICODE
-# define PCRE_BSR_UNICODE 0
-#endif
-   MAKE_ICONSTANT("PCRE_BSR_UNICODE", PCRE_BSR_UNICODE),
-#ifndef PCRE_CASELESS
-# define PCRE_CASELESS 0
-#endif
    MAKE_ICONSTANT("PCRE_CASELESS", PCRE_CASELESS),
-#ifndef PCRE_DUPNAMES
-# define PCRE_DUPNAMES 0
-#endif
-   MAKE_ICONSTANT("PCRE_DUPNAMES", PCRE_DUPNAMES),
-#ifndef PCRE_DOLLAR_ENDONLY
-# define PCRE_DOLLAR_ENDONLY 0
-#endif
    MAKE_ICONSTANT("PCRE_DOLLAR_ENDONLY", PCRE_DOLLAR_ENDONLY),
-#ifndef PCRE_DOTALL
-# define PCRE_DOTALL 0
-#endif
    MAKE_ICONSTANT("PCRE_DOTALL", PCRE_DOTALL),
-#ifndef PCRE_EXTENDED
-# define PCRE_EXTENDED 0
-#endif
    MAKE_ICONSTANT("PCRE_EXTENDED", PCRE_EXTENDED),
-#ifndef PCRE_EXTRA
-# define PCRE_EXTRA 0
-#endif
    MAKE_ICONSTANT("PCRE_EXTRA", PCRE_EXTRA),
-#ifndef PCRE_FIRSTLINE
-# define PCRE_FIRSTLINE 0
-#endif
-   MAKE_ICONSTANT("PCRE_FIRSTLINE", PCRE_FIRSTLINE),
-#ifndef PCRE_JAVASCRIPT_COMPAT
-# define PCRE_JAVASCRIPT_COMPAT 0
-#endif
-   MAKE_ICONSTANT("PCRE_JAVASCRIPT_COMPAT", PCRE_JAVASCRIPT_COMPAT),
-#ifndef PCRE_MULTILINE
-# define PCRE_MULTILINE 0
-#endif
    MAKE_ICONSTANT("PCRE_MULTILINE", PCRE_MULTILINE),
-#ifndef PCRE_NEVER_UTF
-# define PCRE_NEVER_UTF 0
-#endif
-   MAKE_ICONSTANT("PCRE_NEVER_UTF", PCRE_NEVER_UTF),
-#ifndef PCRE_NEWLINE_ANY
-# define PCRE_NEWLINE_ANY 0
-#endif
-   MAKE_ICONSTANT("PCRE_NEWLINE_ANY", PCRE_NEWLINE_ANY),
-#ifndef PCRE_NEWLINE_ANYCRLF
-# define PCRE_NEWLINE_ANYCRLF 0
-#endif
-   MAKE_ICONSTANT("PCRE_NEWLINE_ANYCRLF", PCRE_NEWLINE_ANYCRLF),
-#ifndef PCRE_NEWLINE_CR
-# define PCRE_NEWLINE_CR 0
-#endif
-   MAKE_ICONSTANT("PCRE_NEWLINE_CR", PCRE_NEWLINE_CR),
-#ifndef PCRE_NEWLINE_CRLF
-# define PCRE_NEWLINE_CRLF 0
-#endif
-   MAKE_ICONSTANT("PCRE_NEWLINE_CRLF", PCRE_NEWLINE_CRLF),
-#ifndef PCRE_NEWLINE_LF
-# define PCRE_NEWLINE_LF 0
-#endif
-   MAKE_ICONSTANT("PCRE_NEWLINE_LF", PCRE_NEWLINE_LF),
-#ifndef PCRE_NO_START_OPTIMIZE
-# define PCRE_NO_START_OPTIMIZE 0
-#endif
-   MAKE_ICONSTANT("PCRE_NO_START_OPTIMIZE", PCRE_NO_START_OPTIMIZE),
-#ifndef PCRE_NOTEMPTY
-# define PCRE_NOTEMPTY 0
-#endif
-   MAKE_ICONSTANT("PCRE_NOTEMPTY", PCRE_NOTEMPTY),
-#ifndef PCRE_NO_AUTO_CAPTURE
-# define PCRE_NO_AUTO_CAPTURE 0
-#endif
-   MAKE_ICONSTANT("PCRE_NO_AUTO_CAPTURE", PCRE_NO_AUTO_CAPTURE),
-#ifndef PCRE_NO_AUTO_POSSESS
-# define PCRE_NO_AUTO_POSSESS 0
-#endif
-   MAKE_ICONSTANT("PCRE_NO_AUTO_POSSESS", PCRE_NO_AUTO_POSSESS),
-#ifndef PCRE_NO_UTF8_CHECK
-# define PCRE_NO_UTF8_CHECK 0
-#endif
-   MAKE_ICONSTANT("PCRE_NO_UTF8_CHECK", PCRE_NO_UTF8_CHECK),
-#ifndef PCRE_UCP
-# define PCRE_UCP 0
-#endif
-   MAKE_ICONSTANT("PCRE_UCP", PCRE_UCP),
-#ifndef PCRE_UNGREEDY
-# define PCRE_UNGREEDY 0
-#endif
    MAKE_ICONSTANT("PCRE_UNGREEDY", PCRE_UNGREEDY),
-#ifndef PCRE_UTF8
-# define PCRE_UTF8 0
-#endif
    MAKE_ICONSTANT("PCRE_UTF8", PCRE_UTF8),
 
    /* exec options */
-#ifndef PCRE_NOTBOL
-# define PCRE_NOTBOL 0
-#endif
    MAKE_ICONSTANT("PCRE_NOTBOL", PCRE_NOTBOL),
-#ifndef PCRE_NOTEOL
-# define PCRE_NOTEOL 0
-#endif
    MAKE_ICONSTANT("PCRE_NOTEOL", PCRE_NOTEOL),
-#ifndef PCRE_NOTEMPTY
-# define PCRE_NOTEMPTY 0
-#endif
    MAKE_ICONSTANT("PCRE_NOTEMPTY", PCRE_NOTEMPTY),
-#ifndef PCRE_PARTIAL_SOFT
-# define PCRE_PARTIAL_SOFT 0
-#endif
-   MAKE_ICONSTANT("PCRE_PARTIAL_SOFT", PCRE_PARTIAL_SOFT),
-#ifndef PCRE_DFA_SHORTEST
-# define PCRE_DFA_SHORTEST 0
-#endif
-   MAKE_ICONSTANT("PCRE_DFA_SHORTEST", PCRE_DFA_SHORTEST),
-#ifndef PCRE_DFA_RESTART
-# define PCRE_DFA_RESTART 0
-#endif
-   MAKE_ICONSTANT("PCRE_DFA_RESTART", PCRE_DFA_RESTART),
-#ifndef PCRE_PARTIAL_HARD
-# define PCRE_PARTIAL_HARD 0
-#endif
-   MAKE_ICONSTANT("PCRE_PARTIAL_HARD", PCRE_PARTIAL_HARD),
-#ifndef PCRE_NOTEMPTY_ATSTART
-# define PCRE_NOTEMPTY_ATSTART 0
-#endif
-   MAKE_ICONSTANT("PCRE_NOTEMPTY_ATSTART", PCRE_NOTEMPTY_ATSTART),
-
    SLANG_END_ICONST_TABLE
 };
 
