@@ -1,6 +1,6 @@
 /* error handling common to all routines. */
 /*
-Copyright (C) 2004-2017,2018 John E. Davis
+Copyright (C) 2004-2011 John E. Davis
 
 This file is part of the S-Lang Library.
 
@@ -470,7 +470,7 @@ static int queue_message (_pSLerr_Error_Queue_Type *q, char *msg, int msg_type)
 
 static void print_error (int msg_type, SLFUTURE_CONST char *err)
 {
-   SLstrlen_Type len;
+   unsigned int len;
 
    switch (msg_type)
      {
@@ -538,9 +538,9 @@ static void print_queue (void)
 char *_pSLerr_get_error_from_queue (_pSLerr_Error_Queue_Type *q, int type)
 {
    Error_Message_Type *m;
-   SLstrlen_Type len;
+   unsigned int len;
    char *err, *err1, *err_max;
-   SLstrlen_Type nl_len;
+   int nl_len;
 
    if ((q == NULL)
        && (NULL == (q = Default_Error_Queue)))
@@ -571,7 +571,7 @@ char *_pSLerr_get_error_from_queue (_pSLerr_Error_Queue_Type *q, int type)
      {
 	if (m->msg_type == type)
 	  {
-	     SLstrlen_Type dlen = strlen (m->msg);
+	     unsigned int dlen = strlen (m->msg);
 	     strcpy (err1, m->msg);
 	     err1 += dlen;
 	     if (nl_len && (err1 != err_max))
@@ -776,12 +776,12 @@ void SLang_vmessage (SLFUTURE_CONST char *fmt, ...)
 /* This routine does not queue messages.  It is used for tracing, etc. */
 void _pSLerr_dump_msg (SLFUTURE_CONST char *fmt, ...)
 {
+   char buf[1024];
    va_list ap;
 
    va_start (ap, fmt);
    if (SLang_Dump_Routine != NULL)
      {
-	char buf[1024];
 	(void) SLvsnprintf (buf, sizeof (buf), fmt, ap);
 	(*SLang_Dump_Routine) (buf);
      }
@@ -805,31 +805,20 @@ int _pSLerr_set_error_queue (_pSLerr_Error_Queue_Type *q)
    return 0;
 }
 
-#if defined(__WIN32__)
-#include <crtdbg.h>  /* For _CrtSetReportMode */
-/* See <https://msdn.microsoft.com/en-us/library/ksazx244%28v=vs.140%29.aspx>
- * for an explanation of the invalid_parm_handler.  The default
- * handler will cause the program to terminate on code such as:
- *
- *  FILE *fp = fdopen (fd);
- *  close (fd);
- *  fclose (fp);  <--- underlying descriptor has been closed.
- *
- * On POSIX systems, fclose will fail with errno == EBADF.
- */
-static void invalid_parm_handler (const wchar_t* expression,
-				  const wchar_t* function,
-				  const wchar_t* file,
-				  unsigned int line,
-				  uintptr_t pReserved)
+int _pSLerr_init (void)
 {
-   (void) expression;
-   (void) function;
-   (void) file;
-   (void) line;
-   (void) pReserved;
+   if (Default_Error_Queue == NULL)
+     {
+	Suspend_Error_Messages = 0;
+	if (NULL == (Default_Error_Queue = _pSLerr_new_error_queue (1)))
+	  return -1;
+     }
+
+   if (-1 == init_exceptions ())
+     return -1;
+
+   return 0;
 }
-#endif
 
 void _pSLerr_deinit (void)
 {
@@ -841,31 +830,3 @@ void _pSLerr_deinit (void)
    Static_Error_Message = NULL;
 }
 
-int _pSLerr_init (void)
-{
-   static int inited = 0;
-
-#ifdef __WIN32__
-   (void) _set_invalid_parameter_handler (invalid_parm_handler);
-   /* Disable the message box for assertions. */
-   _CrtSetReportMode(_CRT_ASSERT, 0);
-#endif
-
-   if (Default_Error_Queue == NULL)
-     {
-	Suspend_Error_Messages = 0;
-	if (NULL == (Default_Error_Queue = _pSLerr_new_error_queue (1)))
-	  return -1;
-     }
-
-   if (-1 == init_exceptions ())
-     return -1;
-
-   if (inited == 0)
-     {
-	inited = 1;
-	(void) SLang_add_cleanup_function (_pSLerr_deinit);
-     }
-   return 0;
-}
-
