@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2004-2016 John E. Davis
+Copyright (C) 2004-2011 John E. Davis
 
 This file is part of the S-Lang Library.
 
@@ -153,16 +153,13 @@ static int check_api_version (char *file, int api_version)
    return -1;
 }
 
-#if defined(__GNUC__)
-# pragma GCC diagnostic ignored "-Wformat-nonliteral"
-#endif
-static VOID_STAR do_dlsym (VOID_STAR handle, SLFUTURE_CONST char *file, int check_error, SLFUTURE_CONST char *fmt, char *module)
+static FVOID_STAR do_dlsym (VOID_STAR handle, SLFUTURE_CONST char *file, int check_error, SLFUTURE_CONST char *fmt, char *module)
 {
    char symbol[MAX_MODULE_NAME_SIZE + 32];
-   VOID_STAR s;
+   FVOID_STAR s;
 
    SLsnprintf (symbol, sizeof(symbol), fmt, module);
-   if (NULL != (s = (VOID_STAR) dlsym (handle, symbol)))
+   if (NULL != (s = (FVOID_STAR) dlsym (handle, symbol)))
      return s;
 
    if (check_error)
@@ -178,9 +175,6 @@ static VOID_STAR do_dlsym (VOID_STAR handle, SLFUTURE_CONST char *file, int chec
      }
    return NULL;
 }
-#if defined(__GNUC__)
-# pragma GCC diagnostic warning "-Wformat-nonliteral"
-#endif
 
 static Handle_Type *dynamic_link_module (SLFUTURE_CONST char *module)
 {
